@@ -19,8 +19,8 @@
 #include <tdemessagebox.h>
 
 K9Mplayer::K9Mplayer(TQObject  *parent,const char *name,const TQStringList args):MPlayer((TQWidget*)parent) {
-    m_seeking=FALSE;
-    m_initVol=TRUE;
+    m_seeking=false;
+    m_initVol=true;
     m_title=0;
 
     m_process=new TDEProcess(this);
@@ -56,7 +56,7 @@ void K9Mplayer::resizeEvent ( TQResizeEvent * _resizeEvent) {
 
 
 void K9Mplayer::wroteStdin( TDEProcess *_process) {
-    m_canwrite = TRUE;
+    m_canwrite = true;
 }
 
 void K9Mplayer::timeout() {
@@ -96,7 +96,7 @@ void K9Mplayer::setTitle( const TQString & _numTitle,const TQString &_numChapter
     if (!m_process->start( TDEProcess::NotifyOnExit,TDEProcess::All)) {
          KMessageBox::error (tqApp->mainWidget(),i18n("Unable to run %1").arg("mplayer") , i18n("Preview"));
     }
-    m_canwrite=TRUE;
+    m_canwrite=true;
 
     m_position=0;
     slider->setValue(m_position);
@@ -135,13 +135,13 @@ void K9Mplayer::slotNewPosition(int _pos,const TQTime & _time) {
 
 void K9Mplayer::sliderReleased() {
     sendCmd( TQString("seek %1 1").arg((int)slider->value()));
-    m_seeking=FALSE;
+    m_seeking=false;
 }
 
 void K9Mplayer::sliderChanged( int _value) {}
 
 void K9Mplayer::sliderPressed() {
-    m_seeking=TRUE;
+    m_seeking=true;
 
 }
 
@@ -198,7 +198,7 @@ void K9Mplayer::open( k9DVD *_dvd,k9DVDTitle *_title,int chapter) {
     if (_title->getsubPictureCount() >0)
         cbSubActivated( 0);
     if (!m_timer->isActive())
-        m_timer->start(200,FALSE);
+        m_timer->start(200,false);
 
 }
 
@@ -225,7 +225,7 @@ void K9Mplayer::sendCmd( TQString _cmd) {
     }
 
     _cmd +="\n";
-    m_canwrite=FALSE;
+    m_canwrite=false;
     m_process->writeStdin( _cmd.latin1() ,_cmd.length());
 
 }
