@@ -58,7 +58,7 @@ class k9DecodeThread;
 
 
 class kDecMPEG2 : public TQObject  {
-Q_OBJECT
+TQ_OBJECT
   
 public: 
   kDecMPEG2(k9DecodeThread *_thread);
