@@ -40,7 +40,7 @@ k9BackupDlg::k9BackupDlg(TQWidget* parent, const char* name, bool modal, WFlags
     timer = new TQTimer( this );
     time = new TQTime(0,0);
     time->start();
-    connect( timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(timerDone()) );
+    connect( timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(timerDone()) );
     timer->start(500, 0 );
     bAbort->setIconSet(KStdGuiItem::cancel().iconSet());
     bPlay->setIconSet(SmallIcon("media-playback-start"));
@@ -50,7 +50,7 @@ k9BackupDlg::k9BackupDlg(TQWidget* parent, const char* name, bool modal, WFlags
     m_totalSteps=0;
     m_factor="";
     m_progress=0;
-    connect(&m_decoder, TQT_SIGNAL(pixmapReady(TQImage *)), this, TQT_SLOT(drawPixmap(TQImage *)));
+    connect(&m_decoder, TQ_SIGNAL(pixmapReady(TQImage *)), this, TQ_SLOT(drawPixmap(TQImage *)));
     m_stop=false;
     m_playmovie=true;
     m_cpt=0;
