@@ -24,8 +24,8 @@
 #include "k9vamps.h"
 #include "ac.h"
 #include "k9dvdtitleset.h"
-#include <kmessagebox.h>
-#include <kapplication.h>
+#include <tdemessagebox.h>
+#include <tdeapplication.h>
 #include <tqapplication.h>
 #include <tqfileinfo.h>
 
@@ -34,7 +34,7 @@
 #include <stdarg.h>
 #include <errno.h>
 #include <string.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqdir.h>
 #include <kstandarddirs.h>
 #include "k9backupdlg.h"
@@ -353,7 +353,7 @@ void k9DVDBackup::getOutput(uchar * buffer, uint32_t buflen) {
     uchar *temp =buffer;
     TQString sName;
     if ((buflen %2048) !=0)
-        qDebug("getOutput, buffer : %u",buflen);
+        tqDebug("getOutput, buffer : %u",buflen);
     uint end=0;
 
     for (uint itemp=0;itemp<buflen;itemp+=DVD_VIDEO_LB_LEN) {
@@ -502,7 +502,7 @@ uint32_t k9DVDBackup::copyMenu2(int _vts) {
 		nbCells++;
         }
 	//else 
-	    //qDebug() << TQString("cell start sector (%1) exceed menu size (%2)").arg((ptr+i)->start_sector).arg(menuLastSector);
+	    //tqDebug() << TQString("cell start sector (%1) exceed menu size (%2)").arg((ptr+i)->start_sector).arg(menuLastSector);
     }
     cadr.sort();
     vamps->reset();
@@ -735,7 +735,7 @@ uint32_t k9DVDBackup::copyVobu(k9DVDFile  *_fileHandle,uint32_t _startSector,k9V
     if (len==-1) {
        setDummyNavPack(buf,sector); 
        nextVobu=findNextVobu(sector);
-       qDebug ("VOBU : %u Read Error !!!!  ==>  %u",sector,nextVobu);
+       tqDebug ("VOBU : %u Read Error !!!!  ==>  %u",sector,nextVobu);
        badNavPack=true;
     }
     currVobu=_vobu;
@@ -760,7 +760,7 @@ uint32_t k9DVDBackup::copyVobu(k9DVDFile  *_fileHandle,uint32_t _startSector,k9V
     	m_cellCopyList->addInbytes( DVD_VIDEO_LB_LEN);
     else
     	m_cellCopyList->addFrcinbytes(DVD_VIDEO_LB_LEN);
-    uint32_t end;
+    uint32_t end = 0;
 
     if (badNavPack) {
        setDummyPack(buf);
@@ -786,7 +786,7 @@ uint32_t k9DVDBackup::copyVobu(k9DVDFile  *_fileHandle,uint32_t _startSector,k9V
 		for (uint32_t i=0;i< nsectors;i++) {
 			len = _fileHandle->readBlocks ( (sector + 1)+i, 1, buf +(i*DVD_VIDEO_LB_LEN));
 			if (len==-1) {
-			qDebug ("VOBU : %u Read Error !!!!",sector);
+			tqDebug ("VOBU : %u Read Error !!!!",sector);
 			//setDummyPack(buf + (i*DVD_VIDEO_LB_LEN));
 			setDummyPack(buf);
 			nsectors=1;
@@ -883,13 +883,13 @@ k9Vobu * k9DVDBackup::remapOffset(uint32_t _sector,uint32_t *_offset,int _dir) {
 
 
         if ((vobu1 !=NULL) && (vobu2!=NULL)) {
-            *_offset = abs(vobu1->newSector - vobu2->newSector)  | maskOffset1 ;
+            *_offset = labs(vobu1->newSector - vobu2->newSector)  | maskOffset1 ;
             *_offset |= maskOffset2;
             return vobu2;
         }
 
         if (vobu1==NULL && vobu2==NULL)
-            qDebug ("remapOffset : sector not found");
+            tqDebug ("remapOffset : sector not found");
     }
     return vobu2;
 }
@@ -910,7 +910,7 @@ void k9DVDBackup::updateMainIfo() {
     hifo->vmgi_mat->vmg_last_sector= 1+ m_vmgSize+hifo->vmgi_mat->vmgi_last_sector*2;
     if (m_vmgSize >0) {
         if (hifo->vmgi_mat->vmgm_vobs != hifo->vmgi_mat->vmgi_last_sector +1)
-            qDebug ("error in ifo file : vmgm_vobs %u -> %u)",hifo->vmgi_mat->vmgm_vobs,hifo->vmgi_mat->vmgi_last_sector +1);
+            tqDebug ("error in ifo file : vmgm_vobs %u -> %u)",hifo->vmgi_mat->vmgm_vobs,hifo->vmgi_mat->vmgi_last_sector +1);
         hifo->vmgi_mat->vmgm_vobs=hifo->vmgi_mat->vmgi_last_sector +1;
     }
 
@@ -1096,7 +1096,7 @@ void k9DVDBackup::update4Menu(ifo_handle_t *_hifo) {
             uint32_t lastSect= ptr[i].last_sector +1;
             k9Vobu *vobu=remapVobu(&startSect);
             if (vobu == NULL)
-                qDebug ("Error : could not find startSector");
+                tqDebug ("Error : could not find startSector");
             else  {
                 if (remapVobu(&lastSect)==NULL)
                     lastSect=vobu->parent->lastSector;
@@ -1152,7 +1152,7 @@ void k9DVDBackup::updateIfo() {
     //JMP
     if (currTS->menuSize >0) {
         if (hifo->vtsi_mat->vtsm_vobs != hifo->vtsi_mat->vtsi_last_sector +1)
-            qDebug ("error in ifo file %u : vtsm_vobs %u -> %u",currTS->VTS,hifo->vtsi_mat->vtsm_vobs,hifo->vtsi_mat->vtsi_last_sector +1);
+            tqDebug ("error in ifo file %u : vtsm_vobs %u -> %u",currTS->VTS,hifo->vtsi_mat->vtsm_vobs,hifo->vtsi_mat->vtsi_last_sector +1);
         hifo->vtsi_mat->vtsm_vobs= hifo->vtsi_mat->vtsi_last_sector +1 ;
 
     }else
@@ -1309,7 +1309,7 @@ void k9DVDBackup::updateIfo() {
         uint32_t lastSect= ptr[i].last_sector +1;
         k9Vobu *vobu=remapVobu(&startSect);
         if (vobu == NULL)
-            qDebug ("Error : could not find startSector");
+            tqDebug ("Error : could not find startSector");
         else {
             if (remapVobu(&lastSect)==NULL)
                 lastSect= vobu->parent->lastSector;
@@ -1598,7 +1598,7 @@ void k9DVDBackup::updateVob(k9CellList *cellLst) {
                 }
 
             } else {
-                qDebug ("erreur positionning");
+                tqDebug ("erreur positionning");
             }
         }
     }
@@ -1687,7 +1687,7 @@ void k9DVDBackup::forceFactor(double _factor) {
     backupDlg->setFactor(sFactor);
     argFactor =  factor;
     m_forcedFactor=true;
-    qDebug("force factor : %f   min:%f",factor,minFactor);
+    tqDebug("force factor : %f   min:%f",factor,minFactor);
 }
 
 
